
local addon, ns = ...
-- ----------------------------------------------------------------- --
-- Localization metatable function                                   --
-- Instructions for Non-Ace3 method taken from Phanx at WowInterface --
-- http://www.wowinterface.com/portal.php?&id=224&pageid=250         --
-- ----------------------------------------------------------------- --

local L = {};
--[[
ns.L = setmetatable(L,{
	__index = function(t,k)
		local k=tostring(k);
		rawset(t,k,k);
		return k;
	end
});
--]]

local debugMode = "3.14.1-release"=="@".."project-version".."@";
ns.L = setmetatable({}, {
	__newindex = function(t,k,v)
		L[tostring(k)]=tostring(v);
	end,
	__index = function(t, k)
		local k=tostring(k);
		return L[k] or k;
	end
});


-- localization by Blizzard - step 1
L["Achievements"] = ACHIEVEMENTS
L["Archaeology"] = PROFESSIONS_ARCHAEOLOGY
L["ChatChannels"] = CHAT_CHANNELS
L["Clock"] = TIMEMANAGER_TITLE
L["Currency"] = CURRENCY
L["Dungeon"] = LFG_TYPE_DUNGEON
L["Dungeons"] = DUNGEONS
L["Durability"] = DURABILITY
L["Emissary Quests"] = BOUNTY_BOARD_LOCKED_TITLE
L["Equipment"] = BAG_FILTER_EQUIPMENT
L["Exalted"] = FACTION_STANDING_LABEL8
L["Followers"] = GARRISON_FOLLOWERS
L["Friendly"] = FACTION_STANDING_LABEL5
L["Friends"] = FRIENDS
L["Game Menu"] = MAINMENU_BUTTON
L["Garrison"] = GARRISON_LOCATION_TOOLTIP
L["Gold"] = BONUS_ROLL_REWARD_MONEY
L["Guild"] = GUILD
L["Hated"] = FACTION_STANDING_LABEL1
L["Honoured"] = FACTION_STANDING_LABEL6
L["Hostile"] = FACTION_STANDING_LABEL2
L["Inn"] = HOME_INN
L["Mail"] = BUTTON_LAG_MAIL
L["Missions"] = GARRISON_MISSIONS
L["Neutral"] = FACTION_STANDING_LABEL4
L["OptGeneral"] = GENERAL
L["OptMisc"] = AUCTION_SUBCATEGORY_OTHER
L["Professions"] = TRADE_SKILLS
L["Quest Log"] = QUESTLOG_BUTTON
L["Raids"] = RAIDS
L["Reputation"] = REPUTATION
L["Revered"] = FACTION_STANDING_LABEL7
L["Ships"] = GARRISON_SHIPYARD_FOLLOWERS
L["Speed"] = SPEED
L["System"] = CHAT_MSG_SYSTEM
L["Tracking"] = TRACKING
L["Unfriendly"] = FACTION_STANDING_LABEL3
L["Volume"] = VOLUME
L["Wardrobe"] = WARDROBE
L["WorkOrders"] = CAPACITANCE_WORK_ORDERS
L["XP"] = XP


-- localization by Blizzard - step 2
L["FPS"] = FRAMERATE_LABEL:gsub(HEADER_COLON,""):gsub("：",""):trim();
L["Home"], L["World"] = MAINMENUBAR_LATENCY_LABEL:match("%((.*)%).*%((.*)%)");
L["Officer notes"] = OFFICER_NOTE_COLON:gsub(HEADER_COLON,""):gsub("：",""):trim();
L["Realm"] = FRIENDS_LIST_REALM:gsub(HEADER_COLON,""):gsub("：",""):trim(); -- "Realm: "

-- localization by Blizzard - step 3 (by events)
local byItemId = {
	-- [<itemId>] = "<english name>",
};

function ns.LocalizationsOnEvent(event,...) -- executed by core.lua > Broker_Everything:SetScript("OnEvent"...
	if event=="ADDON_LOADED" and addon==... then
		local name;
		for id, key in pairs(byItemId) do
			name = GetItemInfo(id);
			if name then
				L[key] = name;
			end
		end
	elseif event=="GET_ITEM_INFO_RECEIVED" then
		local id = ...;
		if byItemId[id] then
			L[byItemId[id]] = GetItemInfo(id);
		end
	end
end

-- localization by ;) - step 3
local locale = GetLocale();
L["WoWToken"] = ({
	deDE="WoW-Marke",
	esES="Ficha de WoW",
	esMX="Ficha de WoW",
	frFR="Jeton WoW",
	itIT="Gettone WoW",
	koKR="WoW 토큰",
	ptBR="Ficha de WoW",
	ptPT="Ficha de WoW",
	ruRU="Жетон WoW",
	zhCN="魔兽世界时光徽章",
	zhTW="魔獸代幣"
})[locale] or "WoW Token";

L[addon.."_Shortcut"] = "BE";

-- last step: localization filled by curse packager
L["(current)"] = "(current)"
L["(ends soon)"] = "(ends soon)"
L["(finished)"] = "(finished)"
L["(session only)"] = "(session only)"
L["(starts soon)"] = "(starts soon)"
L["* (Asterisk) behind character name if on foreign realm"] = "* (Asterisk) behind character name if on foreign realm"
L["_ (undercore) > [_60 fps]"] = "_ (undercore) > [_60 fps]"
L["+<Collected in this session>"] = "+<Collected in this session>"
L["<Collected>/<Total>"] = "<Collected>/<Total>"
L["0 (zero) > [060 fps]"] = "0 (zero) > [060 fps]"
L["Absolute value"] = "Absolute value"
L["Action"] = "Action"
L["Activate specialization"] = "Activate specialization"
L["Active quests"] = "Active quests"
L["Active since"] = "Active since"
L["Add a currency"] = "Add a currency"
L["Add a profession"] = "Add a profession"
L["Add more space between displayed currencies on broker button"] = "Add more space between displayed currencies on broker button"
L["Add new note"] = "Add new note"
L["Additional time zones"] = "Additional time zones"
L["Addon"] = "Addon"
L["Addon list"] = "Addon list"
L["Addon panel"] = "Addon panel"
L["AddOnLoaded"] = "AddOn loaded..."
L["AddOnLoadedDesc"] = "Show 'AddOn Loaded...' message on logins and UI reloads"
L["AddOns and memory"] = "AddOns and memory"
L["Adjust the count of numbers behind the dot."] = "Adjust the count of numbers behind the dot."
L["All 10 minutes"] = "All 10 minutes"
L["All 20 minutes"] = "All 20 minutes"
L["All 30 seconds"] = "All 30 seconds"
L["All 40 minutes"] = "All 40 minutes"
L["All 5 minutes"] = "All 5 minutes"
L["All realms"] = "All realms"
L["All slots are empty"] = "All slots are empty"
L["AllFactions"] = "All factions"
L["AllFactionsDesc"] = "Show characters from all factions (alliance, horde and neutral) in tooltip"
L["and %d more"] = "and %d more"
L["Any update of the addon memory usage can cause results in fps drops and 'Script ran too long' error messages!"] = "Any update of the addon memory usage can cause results in fps drops and 'Script ran too long' error messages!"
L["Append the BattleTag of your friends to the character name"] = "Append the BattleTag of your friends to the character name"
L["Applicant"] = "Applicant"
L["Applicants"] = "Applicants"
L["ArchaeologyInfoMaxFragements"] = "Fragments limit"
L["ArchaeologyInfoMaxFragementsDesc"] = "Displays the name of the races on broker button who will soon reach the fragment limit."
L["ArchaeologyInfoRequiredFragements"] = "Project solvable"
L["ArchaeologyInfoRequiredFragementsDesc"] = "Displays the name of the races on broker button whose project can be solved."
L["Artifact frame"] = "Artifact frame"
L["Artifact knowledge"] = "Artifact knowledge"
L["Artifact relic are displayable after opening artifact window. Shift Right-Click on your equipped artifact weapon."] = "Artifact relic are displayable after opening artifact window. Shift Right-Click on your equipped artifact weapon."
L["Artifact weapon"] = "Artifact weapon"
L["Artifact weapon not equipped"] = "Artifact weapon not equipped"
L["Artifacts"] = "Artifacts"
L["Auto crap selling - Summary"] = "Auto crap selling - Summary"
L["Automatically repair failed. Not enough money..."] = "Automatically repair failed. Not enough money..."
L["Automatically repair your equipment on opening a merchant with repair option."] = "Automatically repair your equipment on opening a merchant with repair option."
L["Automatically repaired with guild money"] = "Automatically repaired with guild money"
L["Automatically repaired with player money"] = "Automatically repaired with player money"
L["AutoRepair"] = "AutoRepair"
L["available"] = "available"
L["Available blueprints level 3"] = "Available blueprints level 3"
L["Back from missions"] = "Back from missions"
L["Background colored row for status"] = "Background colored row for status"
L["Background reputation bar mode"] = "Background reputation bar mode"
L["Bags"] = "Bags"
L["BagsQualityAll"] = "All quality types"
L["BagsQualityCommon"] = "Only quality types 'Junk' and 'Common'"
L["BagsQualityJunk"] = "Only quality type 'Junk'"
L["BagsQualityNoEmpty"] = "hide empty entries"
L["BagsQualityVendor"] = "vendor price"
L["BattleNet friends"] = "BattleNet friends"
L["blank > [ 60 fps]"] = "blank > [ 60 fps]"
L["Broker"] = "Broker"
L["Broker format"] = "Broker format"
L["Build date"] = "Build date"
L["Build version"] = "Build version"
L["buildings"] = "buildings"
L["Buyable"] = "Buyable"
L["By"] = "By"
L["by guild fund"] = "by guild fund"
L["by player money"] = "by player money"
L["Calendar"] = "Calendar"
L["CalendarBlizzardEvents"] = "Blizzard events"
L["CalendarBlizzardEventsDesc"] = "Display a list of events created by blizzard"
L["CalendarCommunityEvents"] = "Community events"
L["CalendarCommunityEventsDesc"] = "Display a list of community events"
L["CalendarGuildAnnouncements"] = "Guild announcements"
L["CalendarGuildEvents"] = "Guild events"
L["CalendarGuildEventsDesc"] = "Display a list of guild announcements and events"
L["CalendarInvites"] = "Invites"
L["CalendarInvitesDesc"] = "Display a list of player created invites"
L["CalendarInviteStatus"] = "Invite status"
L["Change how much digits display after the dot."] = "Change how much digits display after the dot."
L["Change steps"] = "Change steps"
L["Change the list style."] = "Change the list style."
L["Change the stepping width for volume changes with mousewheel and clicks."] = "Change the stepping width for volume changes with mousewheel and clicks."
L["Change the update interval or disable it."] = "Change the update interval or disable it."
L["CharDataError"] = "Error on data from"
L["CharDataErrorTODO"] = "Delete data or log into this character to fix it"
L["CharsFrom"] = "Show chars from"
L["CharsFromDesc"] = "Show characters from connected realms, same battlegroup or all realms in tooltip"
L["ChatCommands"] = "Chat commands"
L["ChatCommandsDesc"] = "Enable chat commands. Be carefull. Since patch 7.3.2 it is no longer save for AddOns to add chat commands (linked to the Logout/Quit function problem). The result is in false reports about \"<AddOn> has been blocked from an action only available to the Blizzard UI.\"."
L["Chilling"] = "Chilling"
L["Choose how much entries the list of repair costs can have."] = "Choose how much entries the list of repair costs can have."
L["Choose the date format if used in the list of repair costs"] = "Choose the date format if used in the list of repair costs"
L["Choose your addon panel that opens if you rightclick on memory broker or disable the right click option."] = "Choose your addon panel that opens if you rightclick on memory broker or disable the right click option."
L["Choose your favorite"] = "Choose your favorite"
L["Choose your favorite color set in which the percent text in broker should be displayed."] = "Choose your favorite color set in which the percent text in broker should be displayed."
L["Choose your favorite date format"] = "Choose your favorite date format"
L["Choose your favorite display format for the broker button."] = "Choose your favorite display format for the broker button."
L["Choose your favorite website for further informations to a quest."] = "Choose your favorite website for further informations to a quest."
L["Classic realm"] = "Classic realm"
L["ClassSpecs"] = "Class specs"
L["Cleared"] = "Cleared"
L["Click to change your loot specialization"] = "Click to change your loot specialization"
L["ClickOptDesc"] = "Choose your fav. combination of modifier and mouse for:"
L["ClickOptions"] = "Click options"
L["ClickOptMenu"] = "Option menu"
L["ClickOptPanel"] = "Option panel"
L["Client build"] = "Client build"
L["Client info"] = "Client info"
L["Client version"] = "Client version"
L["Close menu"] = "Close menu"
L["CmdEquipInfo"] = "List your equipment sets or equip a set."
L["CmdEquipInvalid"] = "Name of equipmentset are invalid"
L["CmdEquipMiss"] = "%d item(s) are not in your bag"
L["CmdEquipSets"] = "Available Sets:"
L["CmdEquipUsage"] = "Usage: /be equip [SetName]"
L["CmdInfoOptional"] = "Annotation: Chat commands will be optional soon. Blizzard force me to disable chat commands. Reason: Blizzards false reports \\\"<AddOn> has been blocked from an action only available to the Blizzard UI.\\\" since blocking use of Quit/Logout commands for AddOns (patch 7.3.2). Someome forgot to move /quit and /logout to SecureCmdList."
L["CmdNeedReload"] = "UI Reload is required..."
L["CmdResetInfo"] = "Reset all settings"
L["CmdStatusInfo"] = "List of available modules with his status"
L["CmdToggleInfo"] = "Enable/Disable a module"
L["CmdUsage"] = "Chat command list for /be & /broker_everything"
L["CmdVersion"] = "Display current version of Broker_Everything"
L["CoExistDisabled"] = "This option is disabled because other addons:"
L["CoExistOwn"] = "Has its own minimap button."
L["CoExistSimilar"] = "Has similar option to hide the minimap button."
L["CoExistUnsave"] = "Produce errors if this option is enabled."
L["collapsed"] = "collapsed"
L["Coloring limited currencies by total and/or weekly cap."] = "Coloring limited currencies by total and/or weekly cap."
L["Coloring total cap"] = "Coloring total cap"
L["Coloring total/weekly cap"] = "Coloring total/weekly cap"
L["Completed quests"] = "Completed quests"
L["Connected realms"] = "Connected realms"
L["Contested"] = "Contested"
L["Cooldowns"] = "Cooldowns"
L["Coordinates"] = "Coordinates"
L["Coordinates indeterminable"] = "Coordinates indeterminable"
L["Coordination format"] = "Coordination format"
L["Count"] = "Count"
L["Count of data to collect:"] = "Count of data to collect:"
L["Count of watched faction"] = "Count of watched faction"
L["Crap selling options"] = "Crap selling options"
L["Critical low free slots"] = "Critical low free slots"
L["Currency on broker"] = "Currency on broker"
L["Currency on broker - menu"] = "Currency on broker - menu"
L["CurrencyOnBrokerDesc"] = "Choose a currency to display it on broker button"
L["CurrencyOnBrokerPlace1"] = "Place 1"
L["CurrencyOnBrokerPlace2"] = "Place 2"
L["CurrencyOnBrokerPlace3"] = "Place 3"
L["CurrencyOnBrokerPlace4"] = "Place 4"
L["Current / max xp"] = "Current / max xp"
L["Current price:"] = "Current price:"
L["Currently no artifact power items found"] = "Currently no artifact power items found"
L["Currently no battle.net friends online..."] = "Currently no battle.net friends online..."
L["Currently no friends online..."] = "Currently no friends online..."
L["Currently no price available..."] = "Currently no price available..."
L["Currently you have no artifact weapon equipped..."] = "Currently you have no artifact weapon equipped..."
L["Currently you have no artifact weapon obtained..."] = "Currently you have no artifact weapon obtained..."
L["Custom title"] = "Custom title"
L["Custom title in tooltip"] = "Custom title in tooltip"
L["CVarInCombat"] = "Sorry, CVar %s are no longer changeable while combat. Thanks @ Blizzard."
L["CVarScalingInCombat"] = "Changing the scale of the UI during a combat is not a good idea."
L["Daily zone bonus"] = "Daily zone bonus"
L["Darker blue for fully upgraded"] = "Darker blue for fully upgraded"
L["Date"] = "Date"
L["Date format"] = "Date format"
L["Date instead of duration time"] = "Date instead of duration time"
L["Delete a character from the list"] = "Delete a character from the list"
L["Delete note"] = "Delete note"
L["Demoted"] = "Demoted"
L["Deprecated"] = "Deprecated"
L["Difference"] = "Difference"
L["Difference to previous:"] = "Difference to previous:"
L["Difficulty"] = "Difficulty"
L["DifficultyHeroicShort"] = "H"
L["DifficultyMythicShort"] = "M"
L["DifficultyNormalShort"] = "N"
L["DigitGroup"] = "Digit grouping"
L["DigitGroupDesc"] = "Displays large numbers with digit group symbols to make it easily readable"
L["Disable Click options"] = "Disable Click options"
L["Disable the click options on broker button"] = "Disable the click options on broker button"
L["Display '%s' instead of '%s' on chars under level 110 on broker button"] = "Display '%s' instead of '%s' on chars under level 110 on broker button"
L["Display a list of bag by types with free and total summary in tooltip"] = "Display a list of bag by types with free and total summary in tooltip"
L["Display a list of chars on all realms with there mail counts and 3 lowest days before return to sender. Chars with empty mail box aren't displayed."] = "Display a list of chars on all realms with there mail counts and 3 lowest days before return to sender. Chars with empty mail box aren't displayed."
L["Display a list of currently equipped items"] = "Display a list of currently equipped items"
L["Display a list of my chars on same realm with her level and xp"] = "Display a list of my chars on same realm with her level and xp"
L["Display a list of the last repair costs in tooltip"] = "Display a list of the last repair costs in tooltip"
L["Display a list of your equipment sets"] = "Display a list of your equipment sets"
L["Display a list of your other characters and there emissary quest progress in tooltip"] = "Display a list of your other characters and there emissary quest progress in tooltip"
L["Display a red # on not enchanted/enchantable items"] = "Display a red # on not enchanted/enchantable items"
L["Display a T-Set label on items"] = "Display a T-Set label on items"
L["Display a yellow # on items with empty sockets"] = "Display a yellow # on items with empty sockets"
L["Display addon count on broker"] = "Display addon count on broker"
L["Display ammunition name on broker button"] = "Display ammunition name on broker button"
L["Display an item summary list by qualities in tooltip"] = "Display an item summary list by qualities in tooltip"
L["Display Battle.Net-Friends on DesktopApp in tooltip"] = "Display Battle.Net-Friends on DesktopApp in tooltip"
L["Display Battle.Net-Friends on MobileApp in tooltip"] = "Display Battle.Net-Friends on MobileApp in tooltip"
L["Display BattleNet friends in tooltip"] = "Display BattleNet friends in tooltip"
L["Display BattleTag and/or RealID in tooltip"] = "Display BattleTag and/or RealID in tooltip"
L["Display BattleTag in tooltip (BattleNet friend only)"] = "Display BattleTag in tooltip (BattleNet friend only)"
L["Display broadcast message in tooltip (BattleNet friend only)"] = "Display broadcast message in tooltip (BattleNet friend only)"
L["Display client build number on broker"] = "Display client build number on broker"
L["Display client info in tooltip"] = "Display client info in tooltip"
L["Display client version on broker"] = "Display client version on broker"
L["Display count of BattleNet friends on Broker if 'Split friends on Broker' enabled otherwise add BattleNet friends to summary count."] = "Display count of BattleNet friends on Broker if 'Split friends on Broker' enabled otherwise add BattleNet friends to summary count."
L["Display count of friends if 'Split friends on Broker' enabled otherwise add friends to summary count."] = "Display count of friends if 'Split friends on Broker' enabled otherwise add friends to summary count."
L["Display count of needed reputation to next standing of watched faction on broker button"] = "Display count of needed reputation to next reputation level of watched faction on broker button"
L["Display currency total cap in tooltip."] = "Display currency total cap in tooltip."
L["Display currency weekly earned and cap in tooltip."] = "Display currency weekly earned and cap in tooltip."
L["Display current group and instance modes"] = "Display current group and instance modes"
L["Display current/max reputation of watched faction on broker button"] = "Display current/max reputation of watched faction on broker button"
L["Display date in tooltip"] = "Display date in tooltip"
L["Display earn/loss reputation of watched faction on broker button"] = "Display earn/loss reputation of watched faction on broker button"
L["Display empty equipment slots"] = "Display empty equipment slots"
L["Display expired entries in tooltip"] = "Display expired entries in tooltip"
L["Display faction and standing id's in tooltip"] = "Display faction and standing id's in tooltip"
L["Display faction id's in tooltip"] = "Display faction id's in tooltip"
L["Display faction in tooltip (WoW only)"] = "Display faction in tooltip (WoW only)"
L["Display faction in tooltip if available"] = "Display faction in tooltip if available"
L["Display fps in tooltip"] = "Display fps in tooltip"
L["Display fps on broker"] = "Display fps on broker"
L["Display friends in tooltip"] = "Display friends in tooltip"
L["Display game icon or game shortcut in tooltip"] = "Display game icon or game shortcut in tooltip"
L["Display game in second tooltip"] = "Display game in second tooltip"
L["Display green text line from item tooltip like titanforged"] = "Display green text line from item tooltip like titanforged"
L["Display home latency"] = "Display home latency"
L["Display home latency on broker"] = "Display home latency on broker"
L["Display in broker zone and subzone if exists or one of it."] = "Display in broker zone and subzone if exists or one of it."
L["Display in tooltip a list of your sound output hardware."] = "Display in tooltip a list of your sound output hardware."
L["Display inbound traffic on broker"] = "Display inbound traffic on broker"
L["Display interface version on broker"] = "Display interface version on broker"
L["Display latency in tooltip"] = "Display latency in tooltip"
L["Display list of dungeon IDs in tooltip"] = "Display list of dungeon IDs in tooltip"
L["Display list of event IDs in tooltip"] = "Display list of event IDs in tooltip"
L["Display list of lfr IDs in tooltip"] = "Display list of lfr IDs in tooltip"
L["Display list of raid IDs in tooltip"] = "Display list of raid IDs in tooltip"
L["Display list of szenario IDs in tooltip"] = "Display list of szenario IDs in tooltip"
L["Display list of world boss IDs in tooltip"] = "Display list of world boss IDs in tooltip"
L["Display member notes in chat window after his/her login message"] = "Display member notes in chat window after his/her login message"
L["Display member officer notes in chat window after his/her login message"] = "Display member officer notes in chat window after his/her login message"
L["Display memory usage in tooltip"] = "Display memory usage in tooltip"
L["Display memory usage on broker"] = "Display memory usage on broker"
L["Display mobile chatter with own table in tooltip"] = "Display mobile chatter with own table in tooltip"
L["Display mode"] = "Display mode"
L["Display name of watched faction on broker button"] = "Display name of watched faction on broker button"
L["Display notes in second tooltip"] = "Display notes in second tooltip"
L["Display notes in tooltip"] = "Display notes in tooltip"
L["Display one of the selected tracking options in broker text."] = "Display one of the selected tracking options in broker text."
L["Display other bag types like herbalism or mining bags separated on broker button"] = "Display other bag types like herbalism or mining bags separated on broker button"
L["Display outbound traffic on broker"] = "Display outbound traffic on broker"
L["Display ownership on broker button"] = "Display ownership on broker button"
L["Display percent value of need reputation of watched faction on broker button"] = "Display percent value of need reputation of watched faction on broker button"
L["Display percent value of watched faction reputation on broker button"] = "Display percent value of watched faction reputation on broker button"
L["Display profit/loss of the current session in tooltip"] = "Display profit/loss of the current session in tooltip"
L["Display quest id in tooltip"] = "Display quest id in tooltip"
L["Display quest level in tooltip"] = "Display quest level in tooltip"
L["Display quest tags in tooltip"] = "Display quest tags in tooltip"
L["Display quest text in tooltip"] = "Display quest text in tooltip"
L["Display quest zone in tooltip"] = "Display quest zone in tooltip"
L["Display RealID in tooltip if available (BattleNet friend only)"] = "Display RealID in tooltip if available (BattleNet friend only)"
L["Display realm name in tooltip (WoW only)"] = "Display realm name in tooltip (WoW only)"
L["Display reputation collecting for rewards beyond exalted"] = "Display collected reputation for rewards beyond exalted"
L["Display selection"] = "Display selection"
L["Display session earned/loss reputation in tooltip"] = "Display session earned/loss reputation in tooltip"
L["Display session profit in tooltip"] = "Display session profit in tooltip"
L["Display set name on items"] = "Display set name on items"
L["Display shorter Info on broker button. 'Set?' instead of 'Unknown set'. 'No sets' instead of 'No sets found'."] = "Display shorter Info on broker button. 'Set?' instead of 'Unknown set'. 'No sets' instead of 'No sets found'."
L["Display standing of watched faction on broker button"] = "Display standing of watched faction on broker button"
L["Display status like AFK in tooltip"] = "Display status like AFK in tooltip"
L["Display the content of the tooltip shorter"] = "Display the content of the tooltip shorter"
L["Display the currency id's in tooltip"] = "Display the currency id's in tooltip"
L["Display the lowest item durability in broker."] = "Display the lowest item durability in broker."
L["Display the progress of your emissary quests in tooltip"] = "Display the progress of your emissary quests in tooltip"
L["Display the progress of your emissary quests on broker button"] = "Display the progress of your emissary quests on broker button"
L["Display the time with seconds in broker button and tooltip"] = "Display the time with seconds in broker button and tooltip"
L["Display the transport menu without names of spells and items behind the icons."] = "Display the transport menu without names of spells and items behind the icons."
L["Display this month and last month profit in tooltip"] = "Display this month and last month profit in tooltip"
L["Display this week and last week profit in tooltip"] = "Display this week and last week profit in tooltip"
L["Display today and yesterday profit in tooltip"] = "Display today and yesterday profit in tooltip"
L["Display total count of friens and/or BattleNet friends on broker button"] = "Display total count of friens and/or BattleNet friends on broker button"
L["Display total/weekly caps in different colors"] = "Display total/weekly caps in different colors"
L["Display traffic in tooltip"] = "Display traffic in tooltip"
L["Display unit id on broker button"] = "Display unit id on broker button"
L["Display upgrade counter in darker blue on fully upgraded items"] = "Display upgrade counter in darker blue on fully upgraded items"
L["Display upgrade info like 2/6"] = "Display upgrade info like 2/6"
L["Display world latency"] = "Display world latency"
L["Display world latency on broker"] = "Display world latency on broker"
L["Display XP in broker"] = "Display XP in broker"
L["Display your average item level on broker button"] = "Display your average item level on broker button"
L["Display your current equipment set on broker button"] = "Display your current equipment set on broker button"
L["Display zone in second tooltip"] = "Display zone in second tooltip"
L["Display zone in tooltip"] = "Display zone in tooltip"
L["Display zone names"] = "Display zone names"
L["Do not ignore"] = "Do not ignore"
L["Down"] = "Down"
L["Duration"] = "Duration"
L["Earn/loss of watched faction"] = "Earn/loss of watched faction"
L["Edit note"] = "Edit note"
L["Emissary Quests-ShortCut"] = "EQ"
L["EmissaryVendorRecipes"] = "Emissary vendor recipes"
L["EmissaryVendorRecipesDesc"] = "Display a list of emissary vendor recipes with neccessary faction repution"
L["Enable auto crap selling"] = "Enable auto crap selling"
L["Enable auto repair"] = "Enable auto repair"
L["Enable automatically crap selling on opening a mergant frame"] = "Enable automatically crap selling on opening a mergant frame"
L["Enable it from the character info"] = "Enable it from the character info"
L["Enable to play a sound on receiving a new mail message. Default is off"] = "Enable to play a sound on receiving a new mail message. Default is off"
L["Enable/Disable the display of Guild Reputation in tooltip"] = "Enable/Disable the display of Guild Reputation in tooltip"
L["Ends"] = "Ends"
L["Equipment manager is not enabled"] = "Equipment manager is not enabled"
L["Equipped artifact weapon"] = "Equipped artifact weapon"
L["Even larger"] = "Even larger"
L["Experimental"] = "Experimental"
L["Expire date"] = "Expire date"
L["Extend ID"] = "Extend ID"
L["Faction icon in own column"] = "Faction icon in own column"
L["Faction name in own column"] = "Faction name in own column"
L["Failed quests"] = "Failed quests"
L["Fav. website"] = "Fav. website"
L["finished"] = "finished"
L["Flight licenses"] = "Flight licenses"
L["Follower"] = "Follower"
L["Found in your backpack"] = "Found in your backpack"
L["Framenames"] = "Framenames"
L["Free"] = "Free"
L["free job"] = "free job"
L["Free slots"] = "Free slots"
L["Game icon"] = "Game icon"
L["Game shortcut"] = "Game shortcut"
L["Garrison cache forcast"] = "Garrison cache forcast"
L["Gold information"] = "Gold information"
L["GoldCoins"] = "Coin icons"
L["GoldCoinsDesc"] = "Display coin icons behind the money"
L["GoldColor"] = "Gold coloring"
L["GoldColorCoin"] = "Coin colors"
L["GoldColorDesc"] = "Color money values by coin colors, white or leave it to foreign addons."
L["GoldColorWhite"] = "White"
L["GPS"] = "GPS"
L["Group leader"] = "Group leader"
L["Guild MotD"] = "Guild MotD"
L["GuildErrorInviteMissingFunction"] = "Error: Missing invite function"
L["GuildErrorInviteMobile"] = "Error: You've tried to invite a member who is online with mobile app"
L["GuildErrorInviteOffline"] = "Error: You've tried to invite a member who is offline"
L["GuildErrorWhisperOffline"] = "Error: You've tried to whisper to a member who is offline"
L["GuildLog"] = "Guild log"
L["GuildShowChallengesDesc"] = "Add a line for mouseover to display guild challenges on sub tooltip"
L["GuildShowInfoDesc"] = "Add a line for mouseover to display guild info on sub tooltip"
L["GuildTableBg"] = "Table background"
L["GuildTableBgDesc"] = "Show or hide table background color on tooltip for applicants and members."
L["has reached Level %d."] = "has reached Level %d."
L["Hidden random zone dailies"] = "Hidden random zone dailies"
L["Hide all characters who have reached the level cap."] = "Hide all characters who have reached the level cap."
L["Hide all entries with 'Demote' as action."] = "Hide all entries with 'Demote' as action."
L["Hide all entries with 'Invite' as action."] = "Hide all entries with 'Invite' as action."
L["Hide all entries with 'Join' as action."] = "Hide all entries with 'Join' as action."
L["Hide all entries with 'Leave' as action."] = "Hide all entries with 'Leave' as action."
L["Hide all entries with 'Promote' as action."] = "Hide all entries with 'Promote' as action."
L["Hide all entries with 'Remove' as action."] = "Hide all entries with 'Remove' as action."
L["Hide Blizzard's minimap calendar button"] = "Hide Blizzard's minimap calendar button"
L["Hide blizzard's tracking button on minimap"] = "Hide blizzard's tracking button on minimap"
L["Hide calendar button"] = "Hide calendar button"
L["Hide characters at maximum level"] = "Hide characters at maximum level"
L["Hide demotions"] = "Hide demotions"
L["Hide disabled followers"] = "Hide disabled followers"
L["Hide disabled followers in tooltip"] = "Hide disabled followers in tooltip"
L["Hide invites"] = "Hide invites"
L["Hide joins"] = "Hide joins"
L["Hide leaves"] = "Hide leaves"
L["Hide minimap button"] = "Hide minimap button"
L["Hide minimap mail icon"] = "Hide minimap mail icon"
L["Hide promotions"] = "Hide promotions"
L["Hide removes"] = "Hide removes"
L["Hide section 2"] = "Hide section 2"
L["Hide section 2 in tooltip"] = "Hide section 2 in tooltip"
L["Hide section 3"] = "Hide section 3"
L["Hide section 3 in tooltip"] = "Hide section 3 in tooltip"
L["Hide working followers"] = "Hide working followers"
L["Hide working followers in tooltip"] = "Hide working followers in tooltip"
L["HideMoney"] = "Hide money values"
L["HideMoneyCopper"] = "Hide copper"
L["HideMoneyDescBrokerButton"] = "Hide parts of displayable money on broker"
L["HideMoneyDescEverywhere"] = "Hide parts of displayable money. Everywhere. Can be overridden by module options."
L["HideMoneyDescTooltip"] = "Hide parts of displayable money in tooltip"
L["HideMoneySilver"] = "Hide copper & silver"
L["HideMoneyZeros"] = "Hide zero values"
L["Hold shift"] = "Hold shift"
L["Home"] = "Home"
L["Home latency"] = "Home latency"
L["Hostile NPCs"] = "Hostile NPCs"
L["How would you like to view coordinations."] = "How would you like to view coordinations."
L["How would you like to view numeric reputation format."] = "How would you like to view numeric reputation format."
L["How would you like to view the background reputation bar."] = "How would you like to view the background reputation bar."
L["Icon behind character name"] = "Icon behind character name"
L["IconColor"] = "Icon color"
L["IconColorDesc"] = "Change the color of the icons"
L["Icons"] = "Icons"
L["IconSets"] = "Icon sets"
L["IconSetsDesc"] = "Choose an custom icon set"
L["IconSetsInfo"] = "This addon offer the option to change the icons of the broker modules through LibSharedMedia. An example can be found on"
L["IDs"] = "IDs"
L["If you have more than one addon to display memory usage it is recommended to disable the update interval of this addon."] = "If you have more than one addon to display memory usage it is recommended to disable the update interval of this addon."
L["Ignore all"] = "Ignore all"
L["Ignore artifact weapons"] = "Ignore artifact weapons"
L["Ignore main hand"] = "Ignore main hand"
L["Ignore off-hand"] = "Ignore off-hand"
L["iLevel"] = "iLevel"
L["Illusions"] = "Illusions"
L["In progress"] = "In progress"
L["In Questlog"] = "In Questlog"
L["In title"] = "In title"
L["In:"] = "In:"
L["In|nprogress"] = "In|nprogress"
L["Inbound"] = "Inbound"
L["Inbound / Download"] = "Inbound / Download"
L["Inbound traffic"] = "Inbound traffic"
L["Inn"] = "Inn"
L["Input your note here..."] = "Input your note here..."
L["Instances"] = "Instances"
L["Interactive NPCs"] = "Interactive NPCs"
L["Interface version"] = "Interface version"
L["Invasions"] = "Invasions"
L["InvasionsBBDesc"] = "Display it on broker"
L["InvasionsNextIn"] = "Next in"
L["InvasionsNumNext"] = "Number of future appointments"
L["InvasionsTimerRegion"] = "Choose a region"
L["InvasionsTimerRegionAuto"] = "Automatically choosen by client (%s)"
L["InvasionsTTDesc"] = "Display it in tooltip"
L["Invert expansion order"] = "Invert expansion order"
L["Invert order by exspansion in tooltip"] = "Invert order by exspansion in tooltip"
L["Item has empty socket"] = "Item has empty socket"
L["Item is not enchanted"] = "Item is not enchanted"
L["Item summary by quality mode"] = "Item summary by quality mode"
L["Item summary|nby quality"] = "Item summary|nby quality"
L["Jewels cooldown group"] = "Jewels cooldown group"
L["Jobs"] = "Jobs"
L["Keystones"] = "Keystones"
L["Larger"] = "Larger"
L["Last %d repair costs"] = "Last %d repair costs"
L["Last changed:"] = "Last changed:"
L["Last month"] = "Last month"
L["Lastest senders:"] = "Lastest senders:"
L["Latency"] = "Latency"
L["latest %d entries"] = "latest %d entries"
L["Learnable"] = "Learnable"
L["Leather cooldown group"] = "Leather cooldown group"
L["Left in mailbox"] = "Left in mailbox"
L["Left the guild"] = "Left the guild"
L["Level too high"] = "Level too high"
L["List mails on chars"] = "List mails on chars"
L["List of hardware"] = "List of hardware"
L["List of repair costs"] = "List of repair costs"
L["Loaded AddOns"] = "Loaded AddOns"
L["Locale code"] = "Locale code"
L["Location"] = "Location"
L["Louder"] = "Louder"
L["Lowest durability"] = "Lowest durability"
L["Lowest item"] = "Lowest item"
L["Mails"] = "Mails"
L["Main tooltip options"] = "Main tooltip options"
L["max Level"] = "max Level"
L["Max."] = "Max."
L["Max. Level reached"] = "Max. Level reached"
L["Max. list entries"] = "Max. list entries"
L["Memory"] = "Memory"
L["Memory usage"] = "Memory usage"
L["Min."] = "Min."
L["Missing artifact weapon data"] = "Missing artifact weapon data"
L["Mobile app user"] = "Mobile app user"
L["ModDesc-Achievements"] = "Broker to show earned achievements and the current tracking list"
L["ModDesc-Ammo"] = "Broker to show current ammo. (Hunders only)"
L["ModDesc-Archaeology"] = "Broker to show archaeology factions with fragments, keystones and necessary amount of fragments to solve artifacts"
L["ModDesc-Artifact weapon"] = "Broker to display informations about your obtained artifact weapons on broker and in tooltip"
L["ModDesc-Bags"] = "Broker to show total, used and free slots of your bags"
L["ModDesc-Calendar"] = "Broker to show calendar events and invitations"
L["ModDesc-ChatChannels"] = "Broker to show count of users of all chat channels"
L["ModDesc-ClassSpecs"] = "Broker to show and switch your character specializations"
L["ModDesc-Clock"] = "Broker to show local and/or realm time"
L["ModDesc-Currency"] = "Broker to show your currencies"
L["ModDesc-Difficulty"] = "Display options to toggle dungeon/rald difficulty modes, legacy raid size and more"
L["ModDesc-Dungeons"] = "Broker to display a list of all available dungeons across extensions. A second tooltip will be displayed on mouseover an entry and display a list of your other toons and there status (completed or not)."
L["ModDesc-Durability"] = "Broker to show durability of your gear and estimated repair costs"
L["ModDesc-Emissary Quests"] = "Broker to show emissary quests status"
L["ModDesc-Equipment"] = "Broker to show current equipped items and list & modify equipment sets"
L["ModDesc-Followers"] = "Broker to show a list of your follower with level, quality, experience and more"
L["ModDesc-FPS"] = "Broker to show your frames per second in broker button and current session min/max in tooltip"
L["ModDesc-Framenames"] = "Broker to show names of frames under the mouse"
L["ModDesc-Friends"] = "Broker to show you which friends are online on realm and BattleNet"
L["ModDesc-Game Menu"] = "Broker to show combined list of clickable elements from game menu, microbutton bar. It is not recommended to use it in combat."
L["ModDesc-Garrison"] = "Broker to show garrison buildings, worker, active work orders, available blueprints, depending achievements and gives you a garrison cache forecast for all your chars"
L["ModDesc-Gold"] = "Broker to show gold of all your chars and lost and earned money for the current session"
L["ModDesc-GPS"] = "Broker to show the name of the current zone and the coordinates"
L["ModDesc-Guild"] = "Broker to show guild message of the day, your guild reputation, guild members, applicants and mobile app users"
L["ModDesc-GuildLog"] = "Broker to show last entries of the guild log"
L["ModDesc-IDs"] = "Broker to show locked raids, dungeons and world bosses"
L["ModDesc-Invasions"] = "Broker to show timer for current active invasions (or assaults) with zone name and a adjustable list of future appointments"
L["ModDesc-Latency"] = "Broker to show current home and world network latency"
L["ModDesc-Location"] = "Broker to show your current coordinates"
L["ModDesc-Mail"] = "Broker to show incoming mails and stored mails on all your chars"
L["ModDesc-Memory"] = "Broker to show memory usage summary and single addons usage"
L["ModDesc-Missions"] = "Broker to show active and available missions for your followers and ships"
L["ModDesc-Nameplates"] = "Broker to show clickable nameplates options"
L["ModDesc-Notes"] = "Broker to give you a very simple option to note down some informations. A list of notes in tooltip and with a click on it will be opens a small window you can edit it."
L["ModDesc-Order hall"] = "Broker to display order hall upgrade tree and work orders from order hall and kitchen"
L["ModDesc-Professions"] = "Broker to show your profession skills and cooldowns"
L["ModDesc-Quest Log"] = "Broker to show count of quests in your questlog and quest titles in tooltip"
L["ModDesc-Raids"] = "Broker to display a list of all available raids across extensions. A second tooltip will be displayed on mouseover an entry and display a list of your other toons and there status (completed or not)."
L["ModDesc-Reputation"] = "Broker to show faction standing of your character"
L["ModDesc-Ships"] = "Broker to show your naval ships with level, quality, xp and more"
L["ModDesc-Speed"] = "Broker to show swimming, walking, riding and flying speed in broker button, a list of riding skills and currently active speed bonuses"
L["ModDesc-Stuff"] = "Broker to allow you to do...Stuff! Switch to windowed mode, reload ui, logout and quit."
L["ModDesc-Surprise"] = "Broker to have an eye on your surprise item. What is a surprise item? Anything thats needs some days to open it and thats lootable after the time. Can contain random objects like mounts, companions and more."
L["ModDesc-System"] = "Broker to show system infos like fps, traffic, latency and memory in broker and tooltip"
L["ModDesc-Tanaan Jungle Dailies"] = "Broker to show a list of solved/solvable tanaan jungle bosses, dailys, weeklys and bonus zones"
L["ModDesc-Tracking"] = "Broker to show current tracking list with option to change it"
L["ModDesc-Traffic"] = "Broker to show the traffic between blizzard and your game client"
L["ModDesc-Volume"] = "Broker to show current volume and in tooltip all changeable audio options"
L["ModDesc-Wardrobe"] = "Broker to show count of collected transmog templates"
L["ModDesc-WoWToken"] = "Broker to show current gold price for a WoW Token"
L["ModDesc-XP"] = "Broker to show experience from all chars in tooltip and the current character in broker button"
L["ModDesc-ZoneText"] = "Broker to show the name of the current zone"
L["ModKeyA"] = "Alt"
L["ModKeyC"] = "Ctrl"
L["ModKeyDefault"] = "Default (no modifier)"
L["ModKeyLA"] = "Left alt"
L["ModKeyLC"] = "Left ctrl"
L["ModKeyLS"] = "Left shift"
L["ModKeyRA"] = "Right alt"
L["ModKeyRC"] = "Right ctrl"
L["ModKeyRS"] = "Right shift"
L["ModKeyS"] = "Shift"
L["ModsToggle"] = "Enable/Disable modules"
L["ModsToggleDesc"] = "This tab contains a list of all modules for enabling or disabling it."
L["Modules"] = "Modules"
L["ModulesDesc"] = "This tab gives you access to the options of each module."
L["More info in tooltip..."] = "More info in tooltip..."
L["More nameplate options"] = "More nameplate options"
L["More names"] = "More names"
L["MouseBtn"] = "Click"
L["MouseBtnL"] = "Left-click"
L["MouseBtnR"] = "Right-click"
L["Mousewheel"] = "Mousewheel"
L["Mute game sound"] = "Mute game sound"
L["My current broadcast message"] = "My current broadcast message"
L["Name of watched faction"] = "Name of watched faction"
L["Nameplate size"] = "Nameplate size"
L["Nameplates"] = "Nameplates"
L["Nameplates out of combat"] = "Nameplates out of combat"
L["Names/Nameplates on/off"] = "Names/Nameplates on/off"
L["Necessary achievements for blueprints level 3"] = "Necessary achievements for blueprints level 3"
L["need"] = "need"
L["Need (percent) of watched faction"] = "Need (percent) of watched faction"
L["Need achievement"] = "Need achievement"
L["Need excalted reputation:"] = "Need excalted reputation:"
L["Need level"] = "Need level"
L["Need of watched faction"] = "Need of watched faction"
L["Need to next point"] = "Need to next point"
L["New mail"] = "New mail"
L["New mails"] = "New mails"
L["New rank"] = "New rank"
L["next"] = "next"
L["Next knowledge level"] = "Next knowledge level"
L["No active shipments found..."] = "No active shipments found..."
L["No ammo attached"] = "No ammo attached"
L["No ammo found..."] = "No ammo found..."
L["No boss IDs found..."] = "No boss IDs found..."
L["No channels listed..."] = "No channels listed..."
L["No currencies discovered..."] = "No currencies discovered..."
L["No data"] = "No data"
L["No data found"] = "No data found"
L["No data found..."] = "No data found..."
L["No data to display..."] = "No data to display..."
L["No entries found"] = "No entries found"
L["No equipment sets found"] = "No equipment sets found"
L["No followers found..."] = "No followers found..."
L["No friends to diplay. You have both disabled for tooltip"] = "No friends to diplay. You have both disabled for tooltip"
L["No guild"] = "No guild"
L["No instance IDs found..."] = "No instance IDs found..."
L["No item found."] = "No item found."
L["No log entries found..."] = "No log entries found..."
L["No Mail"] = "No Mail"
L["No missions found..."] = "No missions found..."
L["No new mails"] = "No new mails"
L["No professions learned..."] = "No professions learned..."
L["No quests completed or in your quest log..."] = "No quests completed or in your quest log..."
L["No sets"] = "No sets"
L["No sets found"] = "No sets found"
L["No ships found..."] = "No ships found..."
L["No Spec!"] = "No Spec!"
L["No speed bonus found..."] = "No speed bonus found..."
L["No spells, items or toys found"] = "No spells, items or toys found"
L["No Text"] = "No Text"
L["No tracking option active."] = "No tracking option active."
L["None (disable right click)"] = "None (disable right click)"
L["Normal list of log entries"] = "Normal list of log entries"
L["Not equipped"] = "Not equipped"
L["Not learned"] = "Not learned"
L["Notes"] = "Notes"
L["Number of addons"] = "Number of addons"
L["Numeric format"] = "Numeric format"
L["Oldest:"] = "Oldest:"
L["On"] = "On"
L["On hold shift key"] = "On hold shift key"
L["On/Off"] = "On/Off"
L["One time per hour"] = "One time per hour"
L["One time per minute"] = "One time per minute"
L["Oops... You have all 'In tooltip' options disabled. :)"] = "Oops... You have all 'In tooltip' options disabled. :)"
L["Open"] = "Open"
L["Open achievement"] = "Open achievement"
L["Open all bags"] = "Open all bags"
L["Open archaeology frame with choosen faction"] = "Open archaeology frame with choosen faction"
L["Open GM Ticket"] = "Open GM Ticket"
L["Open QuestLog and select quest"] = "Open QuestLog and select quest"
L["Open tracking menu"] = "Open tracking menu"
L["OptAchievBars"] = "Progress bars"
L["OptAchievBarsDesc"] = "Show progress bars in tooltip"
L["OptAchievBrokerPoints"] = "Achievement points"
L["OptAchievBrokerPointsDesc"] = "Display achievement points on broker button"
L["OptAchievBrokerPointsSess"] = "Session points"
L["OptAchievBrokerPointsSessDesc"] = "Display earned achievement points of the current session"
L["OptAchievCat"] = "Achievement categories"
L["OptAchievCatDesc"] = "Show achievement categories in tooltip"
L["OptAchievCompleted"] = "Completed criteria"
L["OptAchievCompletedDesc"] = "Show completed criteria in watch list"
L["OptAchievCriteriaPL"] = "One criteria per line"
L["OptAchievCriteriaPLDesc"] = "Display one plain text criteria per line"
L["OptAchievLast"] = "Last achievements"
L["OptAchievLastDesc"] = "Show the 5 latest earned achievements in tooltip"
L["OptAchievWatchDesc"] = "Show watch list in tooltip"
L["OptArchOrder"] = "Order by continent"
L["OptArchOrderDesc"] = "Order archaeology races by continent"
L["OptArtKnowledge"] = "Show artifact knowledge"
L["OptArtKnowledgeDesc"] = "Show artifact knowledge in broker button"
L["OptArtName"] = "Artifact name"
L["OptArtNameDesc"] = "Show artifact weapon name in broker button"
L["OptartNotEquipped"] = "Show 'not equipped' warning"
L["OptArtNotEquippedDesc"] = "Show 'artifact weapon not equipped' warning in broker button"
L["OptArtOthers"] = "Show your other artifacts"
L["OptArtOthersDesc"] = "Display a list of your other artifacts you have obtainted"
L["OptArtPoints"] = "Points"
L["OptArtPointsDesc"] = "Show spent/available points in broker button"
L["OptArtPower"] = "Show artifact power"
L["OptArtPowerDesc"] = "Show artifact weapon expierence (artifact power) in broker button"
L["OptArtPowerItems"] = "Show artifact power items"
L["OptArtPowerItemsDesc"] = "Display a list of artifact power items found in your bag in tooltip"
L["OptArtPowerTotal"] = "Show total used artifact power"
L["OptArtPowerTotalDesc"] = "Display amount of total used artifact power on current equipped artifact weapon. That doesn't includes point resets!"
L["OptArtRelic"] = "Show artifact relic"
L["OptArtRelicDesc"] = "Display a list of artifact relic slots in tooltip"
L["OptArtRelicILvl"] = "Show relic item level"
L["OptArtRelicILvlDesc"] = "Display relic item level"
L["OptArtReliciLvlInc"] = "Show increase item level by relic"
L["OptArtReliciLvlIncDesc"] = "Display increase item level by relic"
L["OptArtUnused"] = "Show unspend artifact power"
L["OptArtUnusedDesc"] = "Show amount summary of artifact power from items in your backpack in broker button"
L["OptCharData"] = "Character data"
L["OptCharDataDesc"] = "Several modules collecting data about your characters. In this tab you can sort your chars and delete chars from a list or delete all data."
L["OptCharDelAll"] = "Delete all character data"
L["OptCharDelAllDesc"] = "Delete data about all your characters"
L["OptCharInfo1"] = "1. Sort your characters"
L["OptCharInfo1Desc"] = "That means you can sort your chars like character choose panel and all modules with informations about your characters respect this order."
L["OptCharInfo2"] = "2. Delete character data"
L["OptCharInfo2Desc"] = "You can delete all collected data about your characters with a single click."
L["OptCharInfo3"] = "3. You can delete all data"
L["OptCharInfoHeader"] = "Your options on this panel:"
L["OptCharList"] = "List of your characters"
L["Option panel"] = "Option panel"
L["OptMinimap"] = "Broker as Minimap Button"
L["OptMinimapDesc"] = "Create a minimap button for this broker"
L["OptReloadUIRequired"] = "An UI reload is necessary to apply all changes."
L["OptSCM"] = "Screen capture mode"
L["OptSCMDesc"] = "The screen capture mode replaces all characters of a name with wildcards (*) without the first. Your chars in XP, your friends battleTags/RealID and there character names and the character names in your guild and there notes."
L["OptTTHints"] = "Show hints"
L["OptTTHintsDesc"] = "Show hints in tooltips. Light blue colored for clickable elements in tooltip. Brown colored for click options on broker button."
L["Order hall"] = "Order hall"
L["Out:"] = "Out:"
L["Outbound"] = "Outbound"
L["Outbound / Upload"] = "Outbound / Upload"
L["Outbound traffic"] = "Outbound traffic"
L["Pending item info request..."] = "Pending item info request..."
L["Percent color set"] = "Percent color set"
L["Percent count of watched faction"] = "Percent count of watched faction"
L["Pet specialization"] = "Pet specialization"
L["Place"] = "Place"
L["Play sound on new mail"] = "Play sound on new mail"
L["Playtime"] = "Playtime"
L["Post repair actions in chatframe"] = "Post repair actions in chatframe"
L["Post summary of earned gold in chat window"] = "Post summary of earned gold in chat window"
L["Precision"] = "Precision"
L["Prefix"] = "Use prefix"
L["PrefixDesc"] = "Use prefix 'BE..' on module registration at LibDataBroker. This fix problems with other addons with same broker names."
L["Prepend a character to fill displayed fps up to 3 character."] = "Prepend a character to fill displayed fps up to 3 character."
L["Prepend character"] = "Prepend character"
L["Price history"] = "Price history"
L["Price history (last 5 changes)"] = "Price history (last 5 changes)"
L["Profession menu"] = "Profession menu"
L["ProfessionTTOnClick"] = "Clickable tooltip lines"
L["ProfessionTTOnClickDesc"] = "Enables clickable tooltip lines with the same functionality like profession menu to open trade skill windows."
L["Program"] = "Program"
L["Promoted"] = "Promoted"
L["Quest id"] = "Quest id"
L["Quest level"] = "Quest level"
L["Quest name"] = "Quest name"
L["Quest tags"] = "Quest tags"
L["Quest zone"] = "Quest zone"
L["QuestId"] = "QuestId"
L["QuestIDs"] = "QuestIDs"
L["QuestTagACC"] = "a"
L["QuestTagGRP"] = "g"
L["QuestTagHD"] = "hc"
L["QuestTagLEG"] = "leg"
L["QuestTagMD"] = "myth"
L["QuestTagND"] = "d"
L["QuestTagPVP"] = "pvp"
L["QuestTagR"] = "r"
L["QuestTagS"] = "s"
L["QuestTagTS"] = "ts"
L["QuestTagWQ"] = "wq"
L["Quieter"] = "Quieter"
L["Random zone dailies"] = "Random zone dailies"
L["Rare bosses"] = "Rare bosses"
L["Reactivate ID"] = "Reactivate ID"
L["Real ID"] = "Real ID"
L["really?"] = "really?"
L["Realm name in character name column"] = "Realm name in character name column"
L["Realm name in own column"] = "Realm name in own column"
L["RealmNames"] = "Realm names"
L["RealmNamesDesc"] = "Show realm names behind charater names in tooltip"
L["Recently"] = "Recently"
L["Recipes from faction vendors"] = "Recipes from faction vendors"
L["Recipes from faction vendors by expansion"] = "Recipes from faction vendors by expansion"
L["Reduce the broker text to a number without text"] = "Reduce the broker text to a number without text"
L["RegionLabel1"] = "North america / Brazil / Oceania"
L["RegionLabel2"] = "Korea"
L["RegionLabel3"] = "Europe / Russia"
L["RegionLabel4"] = "Taiwan"
L["RegionLabel5"] = "China"
L["Remove entry"] = "Remove entry"
L["Remove the currency"] = "Remove the currency"
L["Removed"] = "Removed"
L["Repair info"] = "Repair info"
L["Repair options"] = "Repair options"
L["RepairAll"] = "RepairAll"
L["Reputation dailies"] = "Reputation dailies"
L["Reputation discounts"] = "Reputation discounts"
L["Reputation weeklies"] = "Reputation weeklies"
L["Reset last repairs"] = "Reset last repairs"
L["Reset session earn/loss counter"] = "Reset session earn/loss counter"
L["Reset session profit"] = "Reset session profit"
L["Reward beyond exalted"] = "Reward beyond exalted"
L["Riding skill"] = "Riding skill"
L["Same battlegroup"] = ""
L["Sanctuary"] = "Sanctuary"
L["Save repair costs"] = "Save repair costs"
L["'Save set' should ignore main hand weapon"] = "'Save set' should ignore main hand weapon"
L["'Save set' should ignore off-hand weapon"] = "'Save set' should ignore off-hand weapon"
L["Save the list of repair costs over the session"] = "Save the list of repair costs over the session"
L["Second tooltip options"] = "Second tooltip options"
L["Secondary tooltip options"] = "Secondary tooltip options"
L["Select the maximum free slot count to coloring in red."] = "Select the maximum free slot count to coloring in red."
L["Select the maximum free slot count to coloring in yellow."] = "Select the maximum free slot count to coloring in yellow."
L["Select the maximum number of addons to display, otherwise drag to '0' to display all."] = "Select the maximum number of addons to display, otherwise drag to '0' to display all."
L["Select the maximum number of addons to display, otherwise drag to 'All'."] = "Select the maximum number of addons to display, otherwise drag to 'All'."
L["Select the maximum number of entries from the guild log, otherwise drag to 'All'."] = "Select the maximum number of entries from the guild log, otherwise drag to 'All'."
L["Select to show XP as an absolute value; Deselected will show it as a percentage."] = "Select to show XP as an absolute value; Deselected will show it as a percentage."
L["Separate mobile app user"] = "Separate mobile app user"
L["Separate quests by"] = "Separate quests by"
L["Separate summary by faction (Alliance/Horde)"] = "Separate summary by faction (Alliance/Horde)"
L["Separate tables by actions and 'Show max. entries' used per table."] = "Separate tables by actions and 'Show max. entries' used per table."
L["Separate the quests by header (like Blizzard) or status"] = "Separate the quests by header (like Blizzard) or status"
L["Session"] = "Session"
L["Set"] = "Set"
L["Set your own Title instead of 'Game Menu'"] = "Set your own Title instead of 'Game Menu'"
L["Set?"] = "Set?"
L["Shipments"] = "Shipments"
L["Short Tooltip"] = "Short Tooltip"
L["Short transport menu"] = "Short transport menu"
L["Shorter Broker"] = "Shorter Broker"
L["ShortNum"] = "Short numbers"
L["ShortNumDesc"] = "Display short numbers like 123K instead of 123000"
L["Show a list of your characters with count of chilling, working and followers on missions in tooltip"] = "Show a list of your characters with count of chilling, working and followers on missions in tooltip"
L["Show a list of your characters with count of chilling, working and ships on missions in tooltip"] = "Show a list of your characters with count of chilling, working and ships on missions in tooltip"
L["Show a list of your characters with count of ready and active missions in tooltip"] = "Show a list of your characters with count of ready and active missions in tooltip"
L["Show a list of your characters with count of ready and available targets in tooltip"] = "Show a list of your characters with count of ready and available targets in tooltip"
L["Show active missions"] = "Show active missions"
L["Show active missions in tooltip"] = "Show active missions in tooltip"
L["Show all counts of followers, champions and troops as overall summary on broker button. You can disable single types with following toggles."] = "Show all counts of followers, champions and troops as overall summary on broker button. You can disable single types with following toggles."
L["Show all entries their tainting the environment. Be carefull. Can produce error in combat."] = "Show all entries their tainting the environment. Be carefull. Can produce error in combat."
L["Show all in one"] = "Show all in one"
L["Show ammunition name"] = "Show ammunition name"
L["Show applicants in tooltip"] = "Show applicants in tooltip"
L["Show applicants on broker button"] = "Show applicants on broker button"
L["Show archievements"] = "Show archievements"
L["Show available blueprints in tooltip"] = "Show available blueprints in tooltip"
L["Show available missions"] = "Show available missions"
L["Show available missions in tooltip"] = "Show available missions in tooltip"
L["Show average item level"] = "Show average item level"
L["Show bags by type"] = "Show bags by type"
L["Show bagspace instead used and max. bagslots in broker button"] = "Show bagspace instead used and max. bagslots in broker button"
L["Show BattleNet friends"] = "Show BattleNet friends"
L["Show BattleTag"] = "Show BattleTag"
L["Show BattleTag/RealID"] = "Show BattleTag/RealID"
L["Show blueprints"] = "Show blueprints"
L["Show broadcast message"] = "Show broadcast message"
L["Show cache forcast"] = "Show cache forcast"
L["Show cache forcast in title"] = "Show cache forcast in title"
L["Show champions"] = "Show champions"
L["Show champions in tooltip"] = "Show champions in tooltip"
L["Show champions summary on broker button"] = "Show champions summary on broker button"
L["Show character gold"] = "Show character gold"
L["Show character gold on broker button"] = "Show character gold on broker button"
L["Show characters"] = "Show characters"
L["Show cooldowns"] = "Show cooldowns"
L["Show count of mobile chatter on broker button"] = "Show count of mobile chatter on broker button"
L["Show currency id's"] = "Show currency id's"
L["Show current set"] = "Show current set"
L["Show current zone from guild member"] = "Show current zone from guild member"
L["Show current zone from guild members in tooltip"] = "Show current zone from guild members in tooltip"
L["Show daily profit"] = "Show daily profit"
L["Show date"] = "Show date"
L["Show DesktopApp"] = "Show DesktopApp"
L["Show difference of last change in tooltip"] = "Show difference of last change in tooltip"
L["Show discount"] = "Show discount"
L["Show dungeons"] = "Show dungeons"
L["Show 'empty socket' mark"] = "Show 'empty socket' mark"
L["Show emtpy slots"] = "Show emtpy slots"
L["Show equipment sets"] = "Show equipment sets"
L["Show events"] = "Show events"
L["Show expire date instead of duration"] = "Show expire date instead of duration"
L["Show expired entries"] = "Show expired entries"
L["Show faction"] = "Show faction"
L["Show follower slots"] = "Show follower slots"
L["Show followers"] = "Show followers"
L["Show followers in tooltip"] = "Show followers in tooltip"
L["Show followers on missions"] = "Show followers on missions"
L["Show followers summary on broker button"] = "Show followers summary on broker button"
L["Show freespace"] = "Show freespace"
L["Show friends"] = "Show friends"
L["Show game"] = "Show game"
L["Show garrison cache forecast for all your characters in tooltip"] = "Show garrison cache forecast for all your characters in tooltip"
L["Show garrison cache forecast for your current char in broker button"] = "Show garrison cache forecast for your current char in broker button"
L["Show GMTicket"] = "Show GMTicket"
L["Show GMTickets in tooltip and average wait time in broker button"] = "Show GMTickets in tooltip and average wait time in broker button"
L["Show green text"] = "Show green text"
L["Show group member name with same quests"] = "Show group member name with same quests"
L["Show guild member level up notification in chat frame. (This is not a gratulation bot!)"] = "Show guild member level up notification in chat frame. (This is not a gratulation bot!)"
L["Show Guild Message of the Day in tooltip"] = "Show Guild Message of the Day in tooltip"
L["Show id's"] = "Show id's"
L["Show inventory"] = "Show inventory"
L["Show item summary by quality"] = "Show item summary by quality"
L["Show level up notification"] = "Show level up notification"
L["Show lfr"] = "Show lfr"
L["Show list of buildings there are under construction in tooltip"] = "Show list of buildings there are under construction in tooltip"
L["Show list of reputation discounts in tooltip"] = "Show list of reputation discounts in tooltip"
L["Show max. entries"] = "Show max. entries"
L["Show mission follower slots in tooltip."] = "Show mission follower slots in tooltip."
L["Show mission iLevel"] = "Show mission iLevel"
L["Show mission item level in tooltip."] = "Show mission item level in tooltip."
L["Show mission level"] = "Show mission level"
L["Show mission level in tooltip."] = "Show mission level in tooltip."
L["Show mission type"] = "Show mission type"
L["Show mission type in tooltip."] = "Show mission type in tooltip."
L["Show mobile chatter in tooltip (Armory App users)"] = "Show mobile chatter in tooltip (Armory App users)"
L["Show MobileApp"] = "Show MobileApp"
L["Show monthly profit"] = "Show monthly profit"
L["Show necessary archievements to unlock blueprints in tooltip"] = "Show necessary archievements to unlock blueprints in tooltip"
L["Show 'not enchanted' mark"] = "Show 'not enchanted' mark"
L["Show notes"] = "Show notes"
L["Show notes from guild member"] = "Show notes from guild member"
L["Show notes from guild members in tooltip"] = "Show notes from guild members in tooltip"
L["Show notes in login"] = "Show notes in login"
L["Show off. notes on login"] = "Show off. notes on login"
L["Show officer notes from guild member"] = "Show officer notes from guild member"
L["Show officer notes from guild members in tooltip. (This option will be ignored if you have not permission to read the officer notes)"] = "Show officer notes from guild members in tooltip. (This option will be ignored if you have not permission to read the officer notes)"
L["Show other chars xp"] = "Show other chars xp"
L["Show ownership"] = "Show ownership"
L["Show price history of the 5 last changes in tooltip"] = "Show price history of the 5 last changes in tooltip"
L["Show professions from guild member"] = "Show professions from guild member"
L["Show professions from guild members in tooltip"] = "Show professions from guild members in tooltip"
L["Show PvP honor"] = "Show PvP honor"
L["Show PvP honor in tooltip"] = "Show PvP honor in tooltip"
L["Show PvP honor on broker button"] = "Show PvP honor on broker button"
L["Show PvP talents in tooltip"] = "Show PvP talents in tooltip"
L["Show PvP weekly quests in tooltip"] = "Show PvP weekly quests in tooltip"
L["Show PvP weeklys"] = "Show PvP weeklys"
L["Show quest id"] = "Show quest id"
L["Show quest id's"] = "Show quest id's"
L["Show quest id's in tooltip."] = "Show quest id's in tooltip."
L["Show quest level"] = "Show quest level"
L["Show quest option"] = "Show quest option"
L["Show quest options like track, untrack, share and cancel in tooltip."] = "Show quest options like track, untrack, share and cancel in tooltip."
L["Show quest tag"] = "Show quest tag"
L["Show quest tags"] = "Show quest tags"
L["Show quest tags in tooltip."] = "Show quest tags in tooltip."
L["Show quest text"] = "Show quest text"
L["Show quest unit circles"] = "Show quest unit circles"
L["Show quest zone"] = "Show quest zone"
L["Show quest zone in tooltip."] = "Show quest zone in tooltip."
L["Show QuestIDs in tooltip"] = "Show QuestIDs in tooltip"
L["Show quests to complete 4 world quests for a faction in tooltip."] = "Show quests to complete 4 world quests for a faction in tooltip."
L["Show race from guild member"] = "Show race from guild member"
L["Show race from guild members in tooltip"] = "Show race from guild members in tooltip"
L["Show raids"] = "Show raids"
L["Show rank from guild member"] = "Show rank from guild member"
L["Show rank id from guild members in tooltip"] = "Show rank id from guild members in tooltip"
L["Show rank name from guild members in tooltip"] = "Show rank name from guild members in tooltip"
L["Show ready missions"] = "Show ready missions"
L["Show ready missions in tooltip"] = "Show ready missions in tooltip"
L["Show RealID"] = "Show RealID"
L["Show realm"] = "Show realm"
L["Show seconds"] = "Show seconds"
L["Show separate bag types"] = "Show separate bag types"
L["Show session earn/loss"] = "Show session earn/loss"
L["Show session profit"] = "Show session profit"
L["Show session profit on broker button"] = "Show session profit on broker button"
L["Show Set name"] = "Show Set name"
L["Show short list of PvE talents in tooltip"] = "Show short list of PvE talents in tooltip"
L["Show short quest tags"] = "Show short quest tags"
L["Show short quest tags in tooltip."] = "Show short quest tags in tooltip."
L["Show short talent list"] = "Show short talent list"
L["Show shorter Info for 'Unknown set' and more"] = "Show shorter Info for 'Unknown set' and more"
L["Show shorter title"] = "Show shorter title"
L["Show standing text in tooltip"] = "Show standing text in tooltip"
L["Show status"] = "Show status"
L["Show szenarios"] = "Show szenarios"
L["Show tainting entries"] = "Show tainting entries"
L["Show talents"] = "Show talents"
L["Show talents in tooltip"] = "Show talents in tooltip"
L["Show total cap"] = "Show total cap"
L["Show total count"] = "Show total count"
L["Show total members count on broker button"] = "Show total members count on broker button"
L["Show total/weekly cap"] = "Show total/weekly cap"
L["Show troops"] = "Show troops"
L["Show troops in tooltip"] = "Show troops in tooltip"
L["Show troops summary on broker button"] = "Show troops summary on broker button"
L["Show T-Set"] = "Show T-Set"
L["Show under construction"] = "Show under construction"
L["Show unit id"] = "Show unit id"
L["Show upgrade info"] = "Show upgrade info"
L["Show weekly cap"] = "Show weekly cap"
L["Show weekly profit"] = "Show weekly profit"
L["Show world bosses"] = "Show world bosses"
L["Show world quests"] = "Show world quests"
L["Show your other chars"] = "Show your other chars"
L["Show zone"] = "Show zone"
L["Show/Hide profession cooldowns from all characters."] = "Show/Hide profession cooldowns from all characters."
L["ShowHighestOnly"] = "Show highest value only"
L["SingleRepairSummary"] = "SingleRepairSummary"
L["SizeSuffix-10E12"] = "T"
L["SizeSuffix-10E15"] = "Qa"
L["SizeSuffix-10E18"] = "Qi"
L["SizeSuffix-10E3"] = "K"
L["SizeSuffix-10E6"] = "M"
L["SizeSuffix-10E9"] = "B"
L["Sorry"] = "Sorry"
L["Sorry, In combat lockdown."] = "Sorry, In combat lockdown."
L["Space between currencies"] = "Space between currencies"
L["Special NPCs"] = "Special NPCs"
L["Speed bonus"] = "Speed bonus"
L["Spent artifact power"] = "Spent artifact power"
L["Spent points"] = "Spent points"
L["Split Characters and BattleNet-Friends on Broker Button"] = "Split Characters and BattleNet-Friends on Broker Button"
L["Split friends on Broker"] = "Split friends on Broker"
L["Split summary by faction"] = "Split summary by faction"
L["Standing of watched faction"] = "Standing of watched faction"
L["Standing text"] = "Standing text"
L["Starts"] = "Starts"
L["Status icon"] = "Status icon"
L["Status text"] = "Status text"
L["Stored mails"] = "Stored mails"
L["Stuff"] = "Stuff"
L["Subzone"] = "Subzone"
L["SuffixColor"] = "Suffix coloring"
L["SuffixColorDesc"] = "Enable/Disable class coloring of the information display suffixes. (eg, ms, fps etc)"
L["Summary of earned gold in chat"] = "Summary of earned gold in chat"
L["Surprise"] = "Surprise"
L["Switch (12 or 24 hours)"] = "Switch (12 or 24 hours)"
L["Switch (local or realm time)"] = "Switch (local or realm time)"
L["Switch (percent, absolute, til next and more)"] = "Switch (percent, absolute, til next and more)"
L["Switch between time format 24 hours and 12 hours with AM/PM"] = "Switch between time format 24 hours and 12 hours with AM/PM"
L["TalentLocked"] = "Locked! Your level is too low."
L["TalentUnlocked"] = "Unlocked. Talent selectable..."
L["Tanaan Jungle Dailies"] = "Tanaan Jungle Dailies"
L["TextBar"] = "Text bar"
L["TextBarChar"] = "Character of the text bar"
L["TextBarCharDesc"] = "Choose a character from which the text bar should consist"
L["TextBarDesc"] = "Text bar is a simple row of colored characters act like a graphical status bar."
L["TextBarNum"] = "Number of characters"
L["TextBarNumDesc"] = "Select the number of characters that make up the text bar"
L["The necessary time to collect memory usage of all addons depends on CPU speed, CPU usage, the number of running addons and more."] = "The necessary time to collect memory usage of all addons depends on CPU speed, CPU usage, the number of running addons and more."
L["The secondary tooltip will be displayed by moving the mouse over a friend in main tooltip. The tooltip will be displayed if one of the following options activated."] = "The secondary tooltip will be displayed by moving the mouse over a friend in main tooltip. The tooltip will be displayed if one of the following options activated."
L["The secondary tooltip will be displayed by moving the mouse over a guild member in main tooltip. The tooltip will be displayed if one of the following options activated."] = "The secondary tooltip will be displayed by moving the mouse over a guild member in main tooltip. The tooltip will be displayed if one of the following options activated."
L["This module is waiting for some localized names."] = "This module is waiting for some localized names."
L["This month"] = "This month"
L["Til next level"] = "Til next level"
L["Time to next"] = "Time to next"
L["TimeLabelLocal"] = "L"
L["TimeLabelRealm"] = "R"
L["TimeLocal"] = "Local time"
L["TimeLocalDesc"] = "Display local time on broker button"
L["TimePrefix"] = "Short prefix"
L["TimePrefixDesc"] = "Uses a prefix (L = local / R = realm) for the values on the broker button"
L["TimeRealm"] = "Realm time"
L["TimeRealmDesc"] = "Display realm time on broker button"
L["TimeUTC"] = "UTC time"
L["Title (optional)"] = "Title (optional)"
L["to delete"] = "to delete"
L["to equip"] = "to equip"
L["to update/save"] = "to update/save"
L["Tomorrow"] = "Tomorrow"
L["Tooltip"] = "Tooltip"
L["Total Gold"] = "Total Gold"
L["Total members count"] = "Total members count"
L["Total Memory usage"] = "Total Memory usage"
L["Total slots"] = "Total slots"
L["Total spend power"] = "Total spend power"
L["Tracking options"] = "Tracking options"
L["Traffic"] = "Traffic"
L["Trainer that offer reputation dicount"] = "Trainer that offer reputation dicount"
L["Transmutation cooldown group"] = "Transmutation cooldown group"
L["Try fallback to player money."] = "Try fallback to player money."
L["TTMaxHeight"] = "Max. Tooltip height"
L["TTMaxHeightDesc"] = "Adjust the maximum of tooltip height in percent of your screen height."
L["TTMouse"] = "Allow mouseover"
L["TTMouseDesc"] = "Hold modifier key to use mouseover in tooltip"
L["TTShowMod"] = "Show tooltip by modifier key"
L["TTShowModDesc"] = "Hold modifier key to display tooltip"
L["Under construction"] = "Under construction"
L["Unextend ID"] = "Unextend ID"
L["Unknown set"] = "Unknown set"
L["Unspent talents"] = "Unspent talents"
L["Up"] = "Up"
L["Update interval"] = "Update interval"
L["Upgrade finished"] = "Upgrade finished"
L["Use background colored row for follower status instead to split in separate tables"] = "Use background colored row for follower status instead to split in separate tables"
L["Use custom title as tooltip title"] = "Use custom title as tooltip title"
L["Use guild money"] = "Use guild money"
L["Use guild money on auto repair if you can"] = "Use guild money on auto repair if you can"
L["Use MouseWheel"] = "Use MouseWheel"
L["Use the MouseWheel to change the volume"] = "Use the MouseWheel to change the volume"
L["Value/Cap"] = "Value/Cap"
L["Vendor price"] = "Vendor price"
L["Video Volume"] = "Video Volume"
L["WardrobeArmorDesc"] = "Display count of armor appearances on broker button"
L["WardrobeBrokerArmor"] = "A:"
L["WardrobeBrokerIllusions"] = "I:"
L["WardrobeBrokerSets"] = "S:"
L["WardrobeBrokerWeapons"] = "W:"
L["WardrobeIllusionsDesc"] = "Display count of collected illusions on broker button"
L["WardrobeSetsDesc"] = "Display count of appearance sets on broker button"
L["WardrobeWeaponsDesc"] = "Display count of weapon appearances on broker button"
L["Warn low free slots"] = "Warn low free slots"
L["Watch list"] = "Watch list"
L["Without missions"] = "Without missions"
L["worker"] = "worker"
L["World"] = "World"
L["World bosses"] = "World bosses"
L["World latency"] = "World latency"
L["World quests status update requires min. level:"] = "World quests status update requires min. level:"
L["XP bonus"] = "XP bonus"
L["XP gain disabled"] = "XP gain disabled"
L["You have new mails"] = "You have new mails"
L["You have no quests in your quest log"] = "You have no quests in your quest log"
L["You have not unlocked your order hall"] = "You have not unlocked your order hall"
L["Your guild leadership denied the use of guild money for auto repair."] = "Your guild leadership denied the use of guild money for auto repair."
L["Your other artifacts"] = "Your other artifacts"
L["Your other chars (%s)"] = "Your other chars (%s)"
L["Zone status"] = "Zone status"
L["ZoneText"] = "ZoneText"


